@@ -376,13 +376,12 @@ class LayerEncoder:
 
     # ...............................
     def _read_layer(
-        self,
-        layer_filename,
-        resolution=None,
-        bbox=None,
-        nodata=DEFAULT_NODATA,
-        event_field=None,
-    ):
+            self,
+            layer_filename,
+            resolution=None,
+            bbox=None,
+            nodata=DEFAULT_NODATA,
+            attribute_field=None):
         """Reads a layer for processing.
 
         Args:
@@ -393,8 +392,8 @@ class LayerEncoder:
                 (min x, min y, max x, max y) to use if the layer is a vector layer.
             nodata (numeric): An optional nodata value to use if the layer is a vector
                 layer.
-            event_field (str): If provided, use this field as the burn value for a
-                vector layer.
+            attribute_field (str): If provided, use this shapefile attribute as the data
+                value for a vector layer.
 
         Returns:
             tuple: A tuple containing a window function for returning a portion of the
@@ -405,18 +404,18 @@ class LayerEncoder:
         ext = os.path.splitext(layer_filename)[1]
 
         if ext == '.shp':
-            window_func, nodata_value, events = self._read_vector_layer(
+            window_func, nodata_value, attributes = self._read_vector_layer(
                 layer_filename,
                 resolution=resolution,
                 bbox=bbox,
                 nodata=nodata,
-                event_field=event_field,
+                attribute_field=attribute_field,
             )
         else:
             window_func, nodata_value = self._read_raster_layer(layer_filename)
-            events = set()
+            attributes = set()
 
-        return window_func, nodata_value, events
+        return window_func, nodata_value, attributes
 
     # ...............................
     def _read_raster_layer(self, raster_filename):
@@ -498,30 +497,29 @@ class LayerEncoder:
         resolution=None,
         bbox=None,
         nodata=DEFAULT_NODATA,
-        event_field=None,
+        attribute_field=None,
     ):
         """Reads a vector layer for processing.
 
         Args:
             vector_filename: The vector file path for the layer to read.
-            resolution: An optional resolution to use for the generated data
-                array for the layer.
-            bbox: An optional bounding box in the form
-                (min x, min y, max x, max y) to use for the vector layer.  Will
-                use the shapegrid bounding box if not provided.
-            nodata: An optional nodata value to use if the layer is a vector
+            resolution (numeric): An optional resolution to use for the input data if
+                it is a vector layer.
+            bbox (tuple): An optional bounding box in the form
+                (min x, min y, max x, max y) to use if the layer is a vector layer.
+            nodata (numeric): An optional nodata value to use if the layer is a vector
                 layer.
-            event_field: An optional shapefile attribute to use as the burn
-                value for each cell.  This should be numeric.
+            attribute_field (str): If provided, use this shapefile attribute as the
+                data value for a vector layer.
 
         Returns:
             tuple: A tuple containing a window function for returning a portion of the
                 numpy array generated by the layer, the NODATA value to use with this
-                layer, and a set of distinct events to be used for processing.
+                layer, and a set of distinct attributes to be used for processing.
         """
         options = ['ALL_TOUCHED=TRUE']
-        if event_field is not None:
-            options.append('ATTRIBUTE={}'.format(event_field))
+        if attribute_field is not None:
+            options.append('ATTRIBUTE={}'.format(attribute_field))
 
         if resolution is None:
             resolution = [DEFAULT_SCALE * i for i in self.shapegrid_resolution]
@@ -565,19 +563,19 @@ class LayerEncoder:
             num_cell_sides=self.shapegrid_sides,
         )
 
-        distinct_events = list(np.unique(layer_array))
+        distinct_attributes = list(np.unique(layer_array))
         try:
             # Go through list backwards to safely pop if needed
-            for i in range(len(distinct_events) - 1, -1, -1):
-                if np.isclose(distinct_events[i], nodata):
-                    distinct_events.pop(i)
+            for i in range(len(distinct_attributes) - 1, -1, -1):
+                if np.isclose(distinct_attributes[i], nodata):
+                    distinct_attributes.pop(i)
         except TypeError:  # pragma: no cover
             # This happens if only one value
-            if np.isclose(distinct_events, nodata):
-                distinct_events = []
+            if np.isclose(distinct_attributes, nodata):
+                distinct_attributes = []
             else:
-                distinct_events = [distinct_events]
-        return window_func, nodata, distinct_events
+                distinct_attributes = [distinct_attributes]
+        return window_func, nodata, distinct_attributes
 
     # ...............................
     def encode_biogeographic_hypothesis(
@@ -588,7 +586,7 @@ class LayerEncoder:
         resolution=None,
         bbox=None,
         nodata=DEFAULT_NODATA,
-        event_field=None,
+        attribute_field=None,
     ):
         """Encodes a biogeographic hypothesis layer.
 
@@ -606,27 +604,26 @@ class LayerEncoder:
                 for the data grid.
             nodata: If the layer is a vector, optionally use this as the data
                 grid nodata value.
-            event_field: If the layer is a vector and contains multiple
+            attribute_field: If the layer is a vector and contains multiple
                 hypotheses, use this field to separate the vector file.
 
         Returns:
             list of str: A list of column headers for the newly encoded columns.
         """
-        window_func, nodata, distinct_events = self._read_layer(
+        window_func, nodata, distinct_attributes = self._read_layer(
             layer_filename,
             resolution=resolution,
             bbox=bbox,
-            nodata=nodata,
-            event_field=event_field,
+            nodata=nodata
         )
-        if len(distinct_events) == 2:
-            # Set the events to be opposite sides of same hypothesis
-            distinct_events = [tuple(distinct_events)]
+        if len(distinct_attributes) == 2:
+            # Set the attributes to be opposite sides of same hypothesis
+            distinct_attributes = [tuple(distinct_attributes)]
         encode_func = _get_encode_hypothesis_method(
-            distinct_events, min_coverage, nodata
+            distinct_attributes, min_coverage, nodata
         )
         return self._encode_layer(
-            window_func, encode_func, column_name, num_columns=len(distinct_events)
+            window_func, encode_func, column_name, num_columns=len(distinct_attributes)
         )
 
     # ...............................
@@ -663,13 +660,8 @@ class LayerEncoder:
         Returns:
             list of str: A list of column headers for the newly encoded columns.
         """
-        window_func, nodata, _ = self._read_layer(
-            layer_filename,
-            resolution=resolution,
-            bbox=bbox,
-            nodata=nodata,
-            event_field=attribute_name,
-        )
+        window_func, nodata, _ = self._read_layer(layer_filename, resolution=resolution,
+                                                  bbox=bbox, nodata=nodata)
         encode_func = _get_presence_absence_method(
             min_presence, max_presence, min_coverage, nodata
         )
@@ -707,8 +699,7 @@ class LayerEncoder:
             layer_filename,
             resolution=resolution,
             bbox=bbox,
-            nodata=nodata,
-            event_field=attribute_name,
+            nodata=nodata
         )
         encode_func = _get_mean_value_method(nodata)
         return self._encode_layer(window_func, encode_func, column_name)
@@ -747,8 +738,7 @@ class LayerEncoder:
             layer_filename,
             resolution=resolution,
             bbox=bbox,
-            nodata=nodata,
-            event_field=attribute_name,
+            nodata=nodata
         )
         encode_func = _get_largest_class_method(min_coverage, nodata)
         return self._encode_layer(window_func, encode_func, column_name)
