@@ -1,7 +1,8 @@
 """Convert a lmpy Matrix to a (.csv) file."""
 import argparse
 
-from lmpy import Matrix
+from lmpy.matrix import Matrix
+from lmpy.tools._config_parser import _process_arguments
 
 
 DESCRIPTION = 'Convert a lmpy Matrix to a CSV file with numerical values.'
@@ -29,7 +30,7 @@ def cli():
     parser.add_argument(
         'out_csv_filename', type=str, help='Location to write the converted matrix CSV.'
     )
-    args = parser.parse_args()
+    args = _process_arguments(parser)
     mtx = Matrix.load(args.in_lmm_filename)
     convert_lmm_to_csv(mtx, args.out_csv_filename)
 
